searchData={"items":[{"type":"module","title":"ecies","doc":"This module contains functions for generating EC keys and encrypting, decrypting data using Elliptic Curve Integrated Encryption Scheme (ECIES).","ref":"ecies.html"},{"type":"function","title":"ecies.default_params/0","doc":"Default elliptic curve secp256k1 and set of algorithms used for ECIES encryption/decryption. By default ANSI-X9.63 key derivation function is used with AES-256 CBC encryption and HMAC-SHA256 with 256 bits output authentication tag","ref":"ecies.html#default_params/0"},{"type":"function","title":"ecies.generate_key/0","doc":"Equivalent to generate_key(default_params()) . Generates a new key pair for default secp256k1 curve","ref":"ecies.html#generate_key/0"},{"type":"function","title":"ecies.generate_key/1","doc":"Generates a new key pair for elliptic curve specified in Params under curve key.","ref":"ecies.html#generate_key/1"},{"type":"function","title":"ecies.private_decrypt/2","doc":"Equivalent to private_decrypt(PrivateKey, CipherData, default_params()) . Decrypts the CipherData using the PrivateKey and returns the PlainText Uses the default curve secp256k1 and other params returned from default_params/0","ref":"ecies.html#private_decrypt/2"},{"type":"function","title":"ecies.private_decrypt/3","doc":"Decrypts the CipherData using the PrivateKey and returns the PlainText Uses the set of algorithms and elliptic curve defined in Params argument","ref":"ecies.html#private_decrypt/3"},{"type":"function","title":"ecies.public_encrypt/2","doc":"Equivalent to public_encrypt(OthersPublicKey, PlainText, default_params()) . Encrypts the PlainText using the OthersPublicKey and returns the CipherText Uses the default curve secp256k1 and other params returned from default_params/0","ref":"ecies.html#public_encrypt/2"},{"type":"function","title":"ecies.public_encrypt/3","doc":"Encrypts the PlainText using the OthersPublicKey and returns encrypted data (binary cipher text by default). Uses the set of algorithms and elliptic curve defined in Params argument","ref":"ecies.html#public_encrypt/3"},{"type":"function","title":"ecies.supports/1","doc":"Returns list of supported curves, ciphers and digest types (hashs) that can be used with ecies library","ref":"ecies.html#supports/1"},{"type":"type","title":"ecies.aead_cipher/0","doc":null,"ref":"ecies.html#t:aead_cipher/0"},{"type":"type","title":"ecies.auth_tag/0","doc":"message authentication tag","ref":"ecies.html#t:auth_tag/0"},{"type":"type","title":"ecies.cipher/0","doc":"all ciphers supported by crypto","ref":"ecies.html#t:cipher/0"},{"type":"type","title":"ecies.cipher_text/0","doc":null,"ref":"ecies.html#t:cipher_text/0"},{"type":"type","title":"ecies.cmac_cipher/0","doc":null,"ref":"ecies.html#t:cmac_cipher/0"},{"type":"type","title":"ecies.digest_type/0","doc":null,"ref":"ecies.html#t:digest_type/0"},{"type":"type","title":"ecies.ecies_params/0","doc":null,"ref":"ecies.html#t:ecies_params/0"},{"type":"type","title":"ecies.encrypted_data/0","doc":null,"ref":"ecies.html#t:encrypted_data/0"},{"type":"type","title":"ecies.kdf_fun/0","doc":null,"ref":"ecies.html#t:kdf_fun/0"},{"type":"type","title":"ecies.kdf_type/0","doc":null,"ref":"ecies.html#t:kdf_type/0"},{"type":"type","title":"ecies.keypair/0","doc":null,"ref":"ecies.html#t:keypair/0"},{"type":"type","title":"ecies.mac_bits/0","doc":null,"ref":"ecies.html#t:mac_bits/0"},{"type":"type","title":"ecies.mac_type/0","doc":null,"ref":"ecies.html#t:mac_type/0"},{"type":"type","title":"ecies.named_curve/0","doc":null,"ref":"ecies.html#t:named_curve/0"},{"type":"type","title":"ecies.plain_text/0","doc":null,"ref":"ecies.html#t:plain_text/0"},{"type":"type","title":"ecies.private_key/0","doc":null,"ref":"ecies.html#t:private_key/0"},{"type":"type","title":"ecies.public_key/0","doc":null,"ref":"ecies.html#t:public_key/0"},{"type":"module","title":"ecies_bitcore","doc":"This module provides specific params defaults and overrides compatible with Bitcore ECIES implementation.","ref":"ecies_bitcore.html"},{"type":"function","title":"ecies_bitcore.default_params/0","doc":"Default params compatible with bitcore ECIES implementation. Using secp256k1 elliptic curve, HMAC SHA-256 with 256 bits output authentication tag using AES-128 256 encryption and embedded IV in cipher data. Additionally it provides callbacks for bitcore specific keys and IV derivation functions.","ref":"ecies_bitcore.html#default_params/0"},{"type":"function","title":"ecies_bitcore.params/1","doc":"Equivalent to maps:merge(default_params(), Params) . Utility function for overriding default bitcore compatible params","ref":"ecies_bitcore.html#params/1"},{"type":"module","title":"ecies_electrum","doc":"This module provides specific params defaults and overrides compatible with Electrum, Electron Cash, ElectrumSV and BitcoinSV ECIES implementation.","ref":"ecies_electrum.html"},{"type":"function","title":"ecies_electrum.default_params/0","doc":"Default params compatible with electrum BIE1 ECIES implementation. Using secp256k1 elliptic curve, HMAC SHA-256 with 256 bits output authentication tag using AES-128 CBC encryption and BIE1 message encapsulation. Additionally it provides callback for electrum specific keys and IV derivation function, and proper cipher data encoding.","ref":"ecies_electrum.html#default_params/0"},{"type":"function","title":"ecies_electrum.params/1","doc":"Equivalent to maps:merge(default_params(), Params) . Utility function for overriding default electrum compatible params","ref":"ecies_electrum.html#params/1"},{"type":"module","title":"ecies_geth","doc":"This module provides specific params defaults and overrides compatible with ethereum geth ECIES implementation.","ref":"ecies_geth.html"},{"type":"function","title":"ecies_geth.default_params/0","doc":"Default params compatible with ethereum geth ECIES implementation. Using secp256k1 elliptic curve with NIST SP 800-56 Concatenation Key Derivation Function, AES-128 CTR encryption and HMAC-SHA256 with 128 bits output authentication tag. Additionally it provides callback for geth specific key derivation function, and ensures usage of random IV which is embedded in cipher data.","ref":"ecies_geth.html#default_params/0"},{"type":"function","title":"ecies_geth.params/1","doc":"Equivalent to maps:merge(default_params(), Params) . Utility function for overriding default geth compatible params","ref":"ecies_geth.html#params/1"},{"type":"function","title":"ecies_geth.params_from_curve/1","doc":"Returns params compatible with ethereum geth ECIES implementation for given elliptic curve.","ref":"ecies_geth.html#params_from_curve/1"},{"type":"module","title":"ecies_kdf","doc":"This module contains standard key derivation functions.","ref":"ecies_kdf.html"},{"type":"function","title":"ecies_kdf.concat_kdf/4","doc":"NIST SP 800-56 Concatenation Key Derivation Function (see section 5.8.1).","ref":"ecies_kdf.html#concat_kdf/4"},{"type":"function","title":"ecies_kdf.hkdf/5","doc":"HMAC-based Extract-and-Expand Key Derivation Function (HKDF) See RFC 5869 and RFC 8418","ref":"ecies_kdf.html#hkdf/5"},{"type":"function","title":"ecies_kdf.kdf/4","doc":"The ANSI-X9.63-KDF key derivation function. See RFC 8418","ref":"ecies_kdf.html#kdf/4"},{"type":"module","title":"ecies_pem","doc":"This module contains functions for encoding and decoding public and private keys, as well as pair of these keys, in PEM format.","ref":"ecies_pem.html"},{"type":"function","title":"ecies_pem.decode_keypair/1","doc":"Equivalent to decode_keypair(Pem, ecies:default_params()) . Decodes the given Pem binary representation a PEM formatted &quot;EC PRIVATE KEY&quot; into a key pair { PublicKey , PrivateKey }. If the public key is not included in the given Pem`, it recovers the public key from the private one using `ecies_pubkey:from_private/2 . This is only possible for curves returned by ecies_pubkey:supports_from_private/0 .","ref":"ecies_pem.html#decode_keypair/1"},{"type":"function","title":"ecies_pem.decode_keypair/2","doc":"Equivalent to decode_keypair(Pem, ecies:default_params()) . Decodes the given Pem binary representation a PEM formatted &quot;EC PRIVATE KEY&quot; into a key pair { PublicKey , PrivateKey }. If the public key is not included in the given Pem`, it recovers the public key from the private one using `ecies_pubkey:from_private/2 . This is only possible for curves returned by ecies_pubkey:supports_from_private/0 .","ref":"ecies_pem.html#decode_keypair/2"},{"type":"function","title":"ecies_pem.decode_private/1","doc":"Equivalent to decode_private(Pem, ecies:default_params()) . Decodes the given Pem binary representation a PEM formatted &quot;EC PRIVATE KEY&quot; into a PrivateKey .","ref":"ecies_pem.html#decode_private/1"},{"type":"function","title":"ecies_pem.decode_private/2","doc":"Decodes the given Pem binary representation a PEM formatted &quot;EC PRIVATE KEY&quot; into a PrivateKey .","ref":"ecies_pem.html#decode_private/2"},{"type":"function","title":"ecies_pem.decode_public/1","doc":"Equivalent to decode_public(PemEncodedPublicKey, ecies:default_params()) . Decodes the given Pem binary representation a PEM formatted &quot;PUBLIC KEY&quot; or &quot;EC PRIVATE KEY&quot; into a PublicKey .","ref":"ecies_pem.html#decode_public/1"},{"type":"function","title":"ecies_pem.decode_public/2","doc":"Decodes the given Pem binary representation a PEM formatted &quot;PUBLIC KEY&quot; or &quot;EC PRIVATE KEY&quot; into a PublicKey .","ref":"ecies_pem.html#decode_public/2"},{"type":"function","title":"ecies_pem.encode_keypair/1","doc":"Equivalent to encode_keypair(KeyPair, ecies:default_params()) . Encodes the given KeyPair into PEM &quot;EC PRIVATE KEY&quot; format (public key included).","ref":"ecies_pem.html#encode_keypair/1"},{"type":"function","title":"ecies_pem.encode_keypair/2","doc":"Encodes the given KeyPair into PEM &quot;EC PRIVATE KEY&quot; format (public key included).","ref":"ecies_pem.html#encode_keypair/2"},{"type":"function","title":"ecies_pem.encode_private/1","doc":"Equivalent to encode_private(PrivateKey, ecies:default_params()) . Encodes the given PrivateKey into PEM &quot;EC PRIVATE KEY&quot; format.","ref":"ecies_pem.html#encode_private/1"},{"type":"function","title":"ecies_pem.encode_private/2","doc":"Encodes the given PrivateKey into PEM &quot;EC PRIVATE KEY&quot; format.","ref":"ecies_pem.html#encode_private/2"},{"type":"function","title":"ecies_pem.encode_public/1","doc":"Equivalent to encode_public(PublicKey, ecies:default_params()) . Encodes the given PublicKey into PEM &quot;PUBLIC KEY&quot; format.","ref":"ecies_pem.html#encode_public/1"},{"type":"function","title":"ecies_pem.encode_public/2","doc":"Encodes the given PublicKey into PEM &quot;PUBLIC KEY&quot; format.","ref":"ecies_pem.html#encode_public/2"},{"type":"function","title":"ecies_pem.supports/0","doc":"Returns a list of named curves that are supported by the ecies_pem module. See also: pubkey_cert_records:namedCurves/1 .","ref":"ecies_pem.html#supports/0"},{"type":"function","title":"ecies_pem.supports/1","doc":"Checks if the given NamedCurve is supported by the ecies_pem module.","ref":"ecies_pem.html#supports/1"},{"type":"module","title":"ecies_pubkey","doc":"This module contains functions for compressing, decompressing public key, deriving public key from the given private one and function for EC point multiplication.","ref":"ecies_pubkey.html"},{"type":"function","title":"ecies_pubkey.compress/1","doc":"Equivalent to compress(PubKey, ecies:default_params()) . Compresses the PublicKey , which is a binary representation of an elliptic curve point. Returns the PublicKey unchanged if it is already in compressed form.","ref":"ecies_pubkey.html#compress/1"},{"type":"function","title":"ecies_pubkey.compress/2","doc":"Compresses the PublicKey , which is a binary representation of an elliptic curve point. Returns the PublicKey unchanged if it is already in compressed form.","ref":"ecies_pubkey.html#compress/2"},{"type":"function","title":"ecies_pubkey.decompress/1","doc":"Equivalent to decompress(PublicKey, ecies:default_params()) . Decompresses the PublicKey , which is a binary representation of an elliptic curve point. If the PublicKey is already in decompressed form, it returns the PublicKey unchanged.","ref":"ecies_pubkey.html#decompress/1"},{"type":"function","title":"ecies_pubkey.decompress/2","doc":"Decompresses the PublicKey , which is a binary representation of an elliptic curve point. If the PublicKey is already in decompressed form, it returns the PublicKey unchanged. This function is only valid for curves returned by the supports_decompress/0 function. See also: supports_decompress/0 , supports_decompress/1 .","ref":"ecies_pubkey.html#decompress/2"},{"type":"function","title":"ecies_pubkey.from_private/1","doc":"Equivalent to from_private(PrivateKey, ecies:default_params()) . Calculates a public key from the given PrivateKey .","ref":"ecies_pubkey.html#from_private/1"},{"type":"function","title":"ecies_pubkey.from_private/2","doc":"Calculates a public key from the given PrivateKey . This function is only valid for curves returned by supports_from_private/0 . See also: supports_from_private/0 , supports_from_private/1 .","ref":"ecies_pubkey.html#from_private/2"},{"type":"function","title":"ecies_pubkey.mul/2","doc":"Equivalent to mul(PublicKey, PrivateKey, ecies:default_params()) . Calculates the multiplication of an elliptic curve point given by PublicKey by a scalar given by PrivateKey .","ref":"ecies_pubkey.html#mul/2"},{"type":"function","title":"ecies_pubkey.mul/3","doc":"Calculates the multiplication of an elliptic curve point given by PublicKey by a scalar given by PrivateKey . This function is only valid for curves returned by supports_decompress/0 . See also: supports_decompress/0 , supports_decompress/1 .","ref":"ecies_pubkey.html#mul/3"},{"type":"function","title":"ecies_pubkey.point_bits/1","doc":"Returns the number of bits required for the binary representation of a single coordinate of a point on a given elliptic curve.","ref":"ecies_pubkey.html#point_bits/1"},{"type":"function","title":"ecies_pubkey.supports_decompress/0","doc":"Returns a list of named curves that are supported by the decompress/1 and decompress/2 functions.","ref":"ecies_pubkey.html#supports_decompress/0"},{"type":"function","title":"ecies_pubkey.supports_decompress/1","doc":"Checks if the given NamedCurve is supported by the decompress/1 and decompress/2 functions.","ref":"ecies_pubkey.html#supports_decompress/1"},{"type":"function","title":"ecies_pubkey.supports_from_private/0","doc":"Returns a list of named curves that are supported by the from_private/1 and from_private/2 functions.","ref":"ecies_pubkey.html#supports_from_private/0"},{"type":"function","title":"ecies_pubkey.supports_from_private/1","doc":"Checks if the given NamedCurve is supported by the from_private/1 and from_private/2 functions.","ref":"ecies_pubkey.html#supports_from_private/1"},{"type":"extras","title":"README","doc":"[![Build and Test](https://github.com/simplito/ecies-erl/actions/workflows/erlang.yml/badge.svg)](https://github.com/simplito/ecies-erl/actions/workflows/erlang.yml)\n[![Hex](https://img.shields.io/hexpm/v/ecies.svg)](https://hex.pm/packages/ecies)\n\nCustomizable Erlang native ECIES public-key cryptography library\n================================================================\n\nAn Erlang native library implementing the ECIES (Elliptic Curve Integrated Encryption Scheme) public-key cryptography, providing elliptic curve encryption as an alternative to the deprecated `crypto` `public_encrypt`, `private_decrypt` functions.\n\nMotivation\n----------\n\nThe Erlang OTP team decided to deprecate several `crypto` module functions in OTP 27 (See [functions deprecated in OTP 27](https://www.erlang.org/doc/deprecations.html#functions-deprecated-in-otp-27)).\nNotably, no alternatives were provided for two of them `crypto:public_encrypt/4` and `crypto:private_decrypt/4`.\n\nSome information about potential background of these deprecations can be found [here](https://erlangforums.com/t/security-working-group-minutes/3451/6).\n\nIt is worth mentioning that the above mentioned functions are RSA specific and cannot be used with Elliptic Curve cryptography anyway. \nIn our projects we mainly use Elliptic Curve cryptography and we decided to share this small library for ECIES with the Erlang developers community.  \n\nWe will be happy if you find it useful and use in your project. If you find any ideas for improvements or notice any missing functionality, please open an issue here; even better propose a Pull Request.\n\nUsage\n-----\n\nThe API of library is simple:\n- `ecies:generate_key/0`- can be used to generate public/private key pair\n- `ecies:public_encrypt/2` - for encrypting binary message with given public key\n- `ecies:private_decrypt/2` - for decrypting data using private key corresponding to public key used in `public_encrypt`\n\nExample: \n\n```erlang\n% Bob generates keys, and publish his public key\n{BobPublicKey, BobPrivateKey} = ecies:generate_key(),\n% Alice knowing Bob's public key encrypts a message for him\nData = ecies:public_encrypt(BobPublicKey, <<\"top secret message\">>),\n% Bob is able to decrypt the message using his private key\n<<\"top secret message\">> = ecies:private_decrypt(BobPrivateKey, Data).\n```\n\nIn the above example the default params are used (as returned by `ecies:default_params/0`):\n```erlang\n  #{\n    curve    => secp256k1,\n    cipher   => aes_256_cbc,\n    kdf      => {kdf, sha256},      % ANSI-X9.63 key derivation\n    mac      => {hmac, sha256, 256} % HMAC SHA256 with 256 bits (32 bytes) output\n  }.\n```\n\n##","ref":"readme.html"},{"type":"extras","title":"Openssl interoperability - README","doc":"You can read or write keys in [PEM](https://datatracker.ietf.org/doc/html/rfc7468) format using function from `ecies_pem` module:\n\n- `ecies_pem:decode_public/1` - decodes a public key from the given \"PUBLIC KEY\" or \"EC PRIVATE KEY\" PEM format.\n- `ecies_pem:decode_private/1` - decodes a private key from the given \"EC PRIVATE KEY\" PEM format.\n- `ecies_pem:decode_keypair/1` - decodes both keys from the given \"EC PRIVATE KEY\" PEM format.\n- `ecies_pem:encode_public/1` - encodes a public key into \"PUBLIC KEY\" PEM format.\n- `ecies_pem:encode_private/1` - encodes a private key into \"EC PRIVATE KEY\" PEM format.\n- `ecies_pem:encode_keypair/1` - encodes both keys into \"EC PRIVATE KEY\" PEM format.\n\nExample:\n```shell\nopenssl ecparam -noout -genkey -conv_form compressed -name secp256k1 | tee private.pem\n```\n```erlang\n{ok, Pem} = file:read_file(\"private.pem\"),\n{Pub, Priv} = ecies_pem:decode_keypair(Pem),\nPub = ecies_pem:decode_public(Pem),\nPriv = ecies_pem:decode_private(Pem),\nfile:write_file(\"public.pem\", ecies_pem:encode_public(Pub)).\n```\n```shell\nopenssl ec -pubin -in public.pem -noout -text\n```\n#","ref":"readme.html#openssl-interoperability"},{"type":"extras","title":"Customisation - README","doc":"Using `ecies:generate_key/1`, `ecies:public_encrypt/3`, `ecies:private_decrypt/3` functions which accepts extra `Params` argument you can customize elliptic curve and algorithms used in all steps of encryption/decryption process.\n\nThere are a few library API functions that helps with customisation:\n- `ecies:default_params/0` - returns default set of params\n- `ecies:supports/1`- which can be used to inspect lists of all supported curves, ciphers, hashs (digest types)\n\nWe also provide default params compatible with existing ECIES variants used in some other libraries.\n\n- `ecies_bitcore:default_params/0` - compatible with [bitcore](https://github.com/bitpay/bitcore-ecies/) ECIES implementation\n- `ecies_geth:default_params/0`, `ecies_geth:params_from_curve/1` - compatible with [ethereum's geth](https://github.com/ethereum/go-ethereum) ECIES implementation\n- `ecies_electrum:default_params/0` - compatible with [Electrum](https://github.com/spesmilo/electrum), [Electron Cash](https://github.com/Electron-Cash/Electron-Cash) and [ElectrumSV](https://github.com/electrumsv/electrumsv) ECIES implementation (see also [here](https://github.com/gitzhou/bitcoin-ecies))\n\nExample 1:\n```erlang\n% Alice and Bob agrees on the following params\nParams = #{\n  curve  => x25519,         % Edwards curve 25519\n  kdf    => {hkdf, sha256}, % HMAC-based Extract-and-Expand KDF with SHA256 hash\n  cipher => aes_256_ctr,\n  mac    => {hmac, sha256, 96} % HMAC with SHA256 and 96 bits output\n},\n  % Bob generates keys\n{BobPublicKey, BobPrivateKey} = ecies:generate_key(Params),\n% Alice knowing Bob's public key encrypts a message for him\nData = ecies:public_encrypt(BobPublicKey, <<\"top secret message\">>, Params),\n% Bob is able to decrypt the message using his private key\n<<\"top secret message\">> = ecies:private_decrypt(BobPrivateKey, Data, Params).\n```\nExample 2:\n```erlang\n% Decrypting electrum compatible message\nParams = ecies_electrum:default_params(),\nPrivateKey = binary:decode_hex(<<\"ee3231b5deea48b619814d72a6e1aa04a9f521df281afad5ada89f5393941b1c\">>),\nMessageBase64 = <<\"QklFMQJdmY+9Ys1WjqANreLwXaau62N01r9lebJ9Rp7Az+XRMdNAVgg3J8EEVhni5gn2v+WOD59uDMDp0zY/xPT3IElReQo6XUCSMmgRgRtYl+TUEw==\">>,\n<<\"hello world\">> = ecies:private_decrypt(PrivateKey, MessageBase64, Params).\n```\n\n---\n\nThe list of all supported elliptic curves (`curve` param), ciphers (`cipher` param) and hash functions used by KDF and MAC \nalgorithms can be obtained using `ecies:supports/1` function:\n\n```erlang\n-spec supports(hashs)  -> [digest_type()];\n              (curves) -> [named_curve()];\n              (ciphers) -> [cipher()];\n              (cmac_ciphers) -> [cmac_cipher()];\n              (aead_ciphers) -> [aead_cipher()].\n```\n\n> [!NOTE]\n> For Edwards Curves 25519 and 448 use `x25519`, `x448`, and not `ed25519`, `ed448`\n\nFor key derivation (`kdf` param) you can use:\n```erlang\n-type kdf_type() :: {hkdf, digest_type()} | % HMAC-based Extract-and-Expand Key Derivation Function (HKDF)\n                    {kdf, digest_type()}  | % ANSI-X9.63 KDF\n                    {concat_kdf, digest_type()}  | % NIST SP 800-56 Concatenation Key Derivation Function (see section 5.8.1).\n                    kdf_fun().\n% Custom KDF function\n-type kdf_fun()  :: fun((SharedKey :: binary(), Info :: binary(), Length :: pos_integer()) -> Result :: binary()).\n```\n\nFor message authentication (`mac` param):\n```erlang\n-type mac_type()    :: {hmac, digest_type(), mac_bits()} | % HMAC for given digest function with specified output bits\n                       {cmac, cmac_cipher(), mac_bits()} | % CMAC with AES-*-CBC cipher and given output bits\n                       {aead, mac_bits()}. % Special case when AES CCM/GCM ciphers are used to just specify tag output bits \n-type mac_bits()    :: pos_integer() | default. % default atom means output size equal to given mac key length\n```\n\nLicense\n-------\n`ecies` library is MIT-licensed, as per [LICENSE.md](LICENSE.md).","ref":"readme.html#customisation"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.  \nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [1.1.0] - 2024-08-04\n\nFunctions provided by `m:ecies_electrum` module depends no longer on `libsecp256k1` \nand are working now without any additional dependecies.\nWe also provide functions for standard encoding/decoding of keys in [PEM] format.\n\n#","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- `m:ecies_pem` module with utility functions to encode/decode public/private/keypair to [PEM] format.\n- `m:ecies_pubkey` module with functions for compressing, decompressing public key and deriving public key \n   from the given private one\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Removed - Changelog","doc":"- `ecies_electrum:is_supported/0` as it is no longer needed\n\n## [1.0.0] - 2024-08-01\n\nInitial release\n\n[PEM]: https://datatracker.ietf.org/doc/html/rfc7468\n\n[Unreleased]: https://github.com/simplito/ecies-erl/compare/v1.1.0..develop\n[1.1.0]: https://github.com/simplito/ecies-erl/compare/tag/v1.0.0...v1.1.0\n[1.0.0]: https://github.com/simplito/ecies-erl/releases/tag/v1.0.0","ref":"changelog.html#removed"},{"type":"extras","title":"The MIT License (MIT)","doc":"The MIT License (MIT)\n=====================\n\nCopyright © 2024 Simplito sp. z o.o.\n\nPermission is hereby granted, free of charge, to any person\nobtaining a copy of this software and associated documentation\nfiles (the “Software”), to deal in the Software without\nrestriction, including without limitation the rights to use,\ncopy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the\nSoftware is furnished to do so, subject to the following\nconditions:\n\nThe above copyright notice and this permission notice shall be\nincluded in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND,\nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES\nOF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND\nNONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT\nHOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,\nWHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING\nFROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR\nOTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"}],"content_type":"text/plain","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}